# Kubernetes

These are shared functions and classes for burst plugins that use Kubernetes.
They do not add additional install dependencies, as they are expected to be installed
with their respective plugins.
